@@ -1,7 +1,6 @@
 package App::Office::Contacts::Controller::Exporter::Search;
 
-use strict;
-use warnings;
+use common::sense;
 
 use JSON::XS;
 
@@ -13,7 +12,7 @@ use Sub::Exporter -setup =>
 	/],
 };
 
-our $VERSION = '1.02';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
@@ -23,6 +22,8 @@ sub display
 
 	$self -> log(debug => 'Entered display');
 
+	return if ($self -> validate_post == 0);
+
 	my($json)          = JSON::XS -> new;
 	my($name)          = $self -> query -> param('target') || '';
 	my($organizations) = $self -> param('db') -> organization -> get_organizations($self -> param('user_id'), $name);
