@@ -1,12 +1,11 @@
 package App::Office::Contacts::Controller::Initialize;
 
-use base 'App::Office::Contacts::Controller';
-use strict;
-use warnings;
+use parent 'App::Office::Contacts::Controller';
+use common::sense;
 
 # We don't use Moose because we isa CGI::Application.
 
-our $VERSION = '1.02';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
