@@ -1,14 +1,13 @@
 package App::Office::Contacts::Controller::Search;
 
-use base 'App::Office::Contacts::Controller';
-use strict;
-use warnings;
+use parent 'App::Office::Contacts::Controller';
+use common::sense;
 
 use App::Office::Contacts::Controller::Exporter::Search qw/-all/;
 
 # We don't use Moose because we isa CGI::Application.
 
-our $VERSION = '1.02';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
