@@ -6,7 +6,7 @@ extends 'App::Office::Contacts::View::Base';
 
 use namespace::autoclean;
 
-our $VERSION = '1.02';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
@@ -59,7 +59,7 @@ sub build_add_person_js
 	my($js) = $self -> load_tmpl('update.person.js');
 
 	$js -> param(context     => 'add');
-	$js -> param(form_action => ${$self -> config}{'form_action'});
+	$js -> param(form_action => $self -> script_name);
 
 	return $js -> output;
 
@@ -171,7 +171,7 @@ sub build_update_person_js
 	my($js)   = $self -> load_tmpl('update.person.js');
 
 	$js -> param(context     => 'update');
-	$js -> param(form_action => ${$self -> config}{'form_action'});
+	$js -> param(form_action => $self -> script_name);
 
 	return $js -> output;
 
